@@ -29,9 +29,6 @@ Distributed under the terms of the GNU General Public License v2
 """
 
 
-from __future__ import print_function
-
-
 import os
 import re
 import shlex
@@ -40,10 +37,7 @@ import string
 import sys
 
 
-try: # py2
-	letters = string.letters
-except AttributeError: # py3
-	letters = string.ascii_letters
+letters = string.ascii_letters
 
 
 def get_make_conf_path(EPREFIX):
@@ -81,6 +75,8 @@ def write_make_conf(output, config_path, var, mirror_string):
 		lex.quotes = "\"'"
 		while True:
 			key = lex.get_token()
+			if key is None:
+				break
 
 			if key == var:
 				begin_line = lex.lineno
@@ -139,12 +135,10 @@ def write_repos_conf(output, config_path, var, value):
 			" variable: %s\nChanges NOT SAVED" %var)
 
 
-def get_filesystem_mirrors(output, config_path, sync=False):
+def get_filesystem_mirrors(output, config_path):
 	"""Read the current mirrors and retain mounted filesystems mirrors
 
 	@param config_path: string
-	@param sync: boolean, used to switch between SYNC and GENTOO_MIRRORS
-		make.conf variable target
 	@rtype list
 	"""
 
@@ -159,10 +153,7 @@ def get_filesystem_mirrors(output, config_path, sync=False):
 
 	fsmirrors = []
 
-	if sync:
-		var = 'SYNC'
-	else:
-		var = 'GENTOO_MIRRORS'
+	var = 'GENTOO_MIRRORS'
 
 	output.write('get_filesystem_mirrors(): config_path = %s\n' % config_path, 2)
 	try:
@@ -174,7 +165,7 @@ def get_filesystem_mirrors(output, config_path, sync=False):
 	lex = shlex.shlex(f, posix=True)
 	lex.wordchars = string.digits + letters + r"~!@#$%*_\:;?,./-+{}"
 	lex.quotes = "\"'"
-	p = re.compile('rsync://|http://|ftp://', re.IGNORECASE)
+	p = re.compile('rsync://|http://|https://|ftp://', re.IGNORECASE)
 	while 1:
 		key = get_token(lex)
 		#output.write('get_filesystem_mirrors(): processing key = %s\n' % key, 2)
