@@ -30,9 +30,6 @@ Distributed under the terms of the GNU General Public License v2
 """
 
 
-from __future__ import print_function
-
-
 import os
 import socket
 import sys
@@ -98,7 +95,7 @@ class MirrorSelect(object):
 		@param out: boolean, used to redirect output to stdout
 		@param config_path; string
 		@param sync: boolean, used to switch between sync-uri repos.conf target,
-			SYNC and GENTOO_MIRRORS make.conf variable target
+			and GENTOO_MIRRORS make.conf variable target
 		"""
 		if sync:
 			var = "sync-uri"
@@ -112,7 +109,7 @@ class MirrorSelect(object):
 		if var == "sync-uri" and out:
 			mirror_string = '%s = %s' % (var, ' '.join(hosts))
 		else:
-			mirror_string = '%s="%s"' % (var, ' '.join(hosts))
+			mirror_string = '%s="%s"' % (var, ' \\\n    '.join(hosts))
 
 		if out:
 			self.write_to_output(mirror_string)
@@ -184,6 +181,9 @@ class MirrorSelect(object):
 		group.add_option(
 			"-H", "--http", action="store_true", default=False,
 			help="http only mode. Will not consider hosts of other types")
+		group.add_option(
+			"-S", "--https", action="store_true", default=False,
+			help="https only mode. Will not consider hosts of other types")
 		group.add_option(
 			"-r", "--rsync", action="store_true", default=False,
 			help="rsync mode. Allows you to interactively select your"
@@ -258,8 +258,8 @@ class MirrorSelect(object):
 		# sanity checks
 
 		# hack: check if more than one of these is set
-		if options.http + options.ftp + options.rsync > 1:
-			self.output.print_err('Choose at most one of -H, -f and -r')
+		if options.http + options.https + options.ftp + options.rsync > 1:
+			self.output.print_err('Choose at most one of -H, -S, -f and -r')
 
 		if options.ipv4 and options.ipv6:
 			self.output.print_err('Choose at most one of --ipv4 and --ipv6')
@@ -271,6 +271,9 @@ class MirrorSelect(object):
 		if options.rsync and not (options.interactive or options.all_mirrors):
 			self.output.print_err('rsync servers can only be selected with -i or -a')
 
+		if options.servers and options.all_mirrors:
+			self.output.print_err('Choose at most one of -s or -a')
+
 		if options.interactive and (
 			options.deep or
 			options.blocksize or
@@ -340,12 +343,12 @@ class MirrorSelect(object):
 		@rtype: string
 		'''
 		if rsync:
-			# startwith repos.conf
+			# repos.conf
 			config_path = EPREFIX + '/etc/portage/repos.conf/gentoo.conf'
 			if not os.access(config_path, os.F_OK):
 				self.output.write("Failed access to gentoo.conf: "
 					"%s\n" % os.access(config_path, os.F_OK), 2)
-				return get_make_conf_path(EPREFIX)
+				config_path = None
 			return config_path
 		return get_make_conf_path(EPREFIX)
 
@@ -360,15 +363,15 @@ class MirrorSelect(object):
 		self.output.verbosity = options.verbosity
 		self.output.write("main(); config_path = %s\n" % config_path, 2)
 
-		# reset config_path to find repos.conf/gentoo.conf if it exists
+		# reset config_path to find repos.conf/gentoo.conf
 		if options.rsync:
 			config_path = self.get_conf_path(options.rsync)
 			self.output.write("main(); reset config_path = %s\n" % config_path, 2)
-		else:
-			self.output.write("main(); rsync = %s\n" % str(options.rsync),2)
+		if not config_path:
+			self.output.print_err("main(); Exiting due to missing repos.conf/gentoo.conf file\n")
 
 		fsmirrors = get_filesystem_mirrors(self.output,
-			config_path, options.rsync)
+			config_path)
 
 		hosts = self.get_available_hosts(options)
 
