@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 # coding: utf-8
 
 """Mirrorselect 2.x
@@ -27,8 +27,6 @@ Distributed under the terms of the GNU General Public License v2
 """
 
 
-from __future__ import print_function
-
 from xml.etree import ElementTree as ET
 
 # old url's
